# [PRE-ALPHA RELEASE]
![TOTAL LINES](https://img.shields.io/tokei/lines/github/Animatea/python-multibar)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
